
# 项目简介
astock_loads是专为深度学习模型训练和预测而设计的高质量A股市场数据集。该数据集包括丰富的金融信息，旨在帮助研究人员和开发者构建、验证及部署股市预测模型。

## 特点与优势
+ 实时的A股数据，非交易日缓存数据，交易日会实时更新，并保持节流。
+ 提供多个数据预测的数据结构，包括时间序列等
+ 数据采集周期长，覆盖个股的所有交易数据。
+ 提供简单易用的接口，便于快速集成。

# 数据集概述
包含了众多的数据集。

## 预测涨跌的数据集 TrendLoader
在股市分析中，个股的**历史交易数据**对于预测未来的股价走势具有重要意义。通过时间序列的方式，我们可以将个股的历史数据组织为有用的信息，用于构建预测模型。

### 数据特征

每一日的交易数据包含以下五个基本特征：开盘价，收盘价，最高价，最低价和成交量。

这些特征将作为模型的输入样本，以便于对未来股价走势进行准确的预测。

### 数据样本构建

我们使用连续的 `n` 个交易日数据作为一个数据样本，并使用下面的分类标签来标记未来的股价走势。

### 目标标签

标签的分类为一个**五分类问题**，包括以下类别：

- **猛涨** 🚀
- **微涨** 📈
- **走平** ⚖️
- **微跌** 📉
- **猛跌** ⬇️

通过取之后连续的 `m` 个交易日的数据平均值，我们将基于**涨幅**来定义每个类别。具体分类标准如下：

- **猛涨**：涨幅大于 `l0` 个点
- **微涨**：涨幅大于 `l1` 个点
- **走平**：涨幅大于 `l2` 个点
- **微跌**：涨幅大于 `l3` 个点
- **猛跌**：否则

其中，`l0`, `l1`, `l2`, `l3`是可配置的参数，例如可以设置为 `[5, 2, -2, -5]`。 

### 模型输出

根据上述分类标准，最终的预测结果将转化为一个标准的五分类问题，这将帮助投资者更好地理解和把握股市的动态变化。

